@@ -1,3 +1,21 @@
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Library General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+#
+# See the COPYING file for license information.
+#
+# Copyright (c) 2007 Guillaume Chazarain <guichaz@gmail.com>
+
 import ctypes
 import fnmatch
 import os
@@ -11,8 +29,10 @@ import time
 # the architecture name and the word size.
 IOPRIO_GET_ARCH_SYSCALL = [
     ('alpha',       '*',  443),
+    ('arm*',        '*',  315),
     ('i*86',        '*',  290),
     ('ia64*',       '*', 1275),
+    ('parisc*',     '*',  268),
     ('powerpc*',    '*',  274),
     ('s390*',       '*',  283),
     ('sparc*',      '*',  218),
@@ -23,8 +43,10 @@ IOPRIO_GET_ARCH_SYSCALL = [
 
 IOPRIO_SET_ARCH_SYSCALL = [
     ('alpha',       '*',  442),
+    ('arm*',        '*',  314),
     ('i*86',        '*',  289),
     ('ia64*',       '*', 1274),
+    ('parisc*',     '*',  267),
     ('powerpc*',    '*',  273),
     ('s390*',       '*',  282),
     ('sparc*',      '*',  196),
