@@ -1,3 +1,21 @@
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Library General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+#
+# See the COPYING file for license information.
+#
+# Copyright (c) 2007 Guillaume Chazarain <guichaz@gmail.com>
+
 import curses
 import errno
 import locale
@@ -46,7 +64,7 @@ def format_stats(options, process, duration):
     # Keep in sync with TaskStatsNetlink.members_offsets and
     # IOTopUI.get_data(self)
     def delay2percent(delay): # delay in ns, duration in s
-        return '%.2f %%' % min(99.99, delay / (duration * 10000000.0))
+        return '%.2f' % min(99.99, delay / (duration * 10000000.0))
     if options.accumulated:
         stats = process.stats_accum
         display_format = lambda size, duration: format_size(options, size)
@@ -262,7 +280,6 @@ class IOTopUI(object):
     def handle_key(self, key):
         def toggle_accumulated():
             self.options.accumulated ^= True
-            self.process_list.clear()
         def toggle_only_io():
             self.options.only ^= True
         def toggle_processes():
@@ -347,23 +364,25 @@ class IOTopUI(object):
             stats = format_stats(self.options, p, self.process_list.duration)
             io_delay, swapin_delay, read_bytes, write_bytes = stats
             if Stats.has_blkio_delay_total:
-                delay_stats = '%7s %7s ' % (swapin_delay, io_delay)
+                delay_stats = '%7s %7s' % (swapin_delay, io_delay)
             else:
                 delay_stats = ' ?unavailable?  '
-            line = '%5d %4s %-8s %11s %11s %s' % (
-                p.pid, p.get_ioprio(), p.get_user()[:8], read_bytes,
-                write_bytes, delay_stats)
             cmdline = p.get_cmdline()
             if not self.options.batch:
-                remaining_length = self.width - len(line)
-                if 2 < remaining_length < len(cmdline):
-                    len1 = (remaining_length - 1) // 2
-                    offset2 = -(remaining_length - len1 - 1)
+                line = ' %10s %10s %s' % (
+                   read_bytes, write_bytes, delay_stats)
+                if (len(line) > self.width - 12):
+                    line = ' %10s %10s' % (
+                    read_bytes, write_bytes)
+                cmd_len = self.width - len(line) - 7 
+                if 2 < cmd_len < len(cmdline):
+                    len1 = (cmd_len - 1) // 2
+                    offset2 = -(cmd_len - len1 - 1)
                     cmdline = cmdline[:len1] + '~' + cmdline[offset2:]
-            line += cmdline
-            if not self.options.batch:
-                line = line[:self.width]
-            return line
+                line1 = '%5d %s %s' % (
+                      p.pid, cmdline.rjust(cmd_len), line)
+                line1 = line1[:self.width]
+            return line1
 
         def should_format(p):
             return not self.options.only or \
@@ -389,9 +408,12 @@ class IOTopUI(object):
             pid = '  PID'
         else:
             pid = '  TID'
-        titles = [pid, '  PRIO', '  USER', '     DISK READ', '  DISK WRITE',
-                  '  SWAPIN', '      IO', '    COMMAND']
         lines = self.get_data()
+        if (self.width > 50): # empirical value for osso-xterm
+                titles = [pid, 'COMMAND'.rjust(self.width - 44), '      READ', '      WRITE',
+                    '      SWAP', '     IO']
+        else:
+                titles = [pid, 'COMMAND'.rjust(self.width - 28), '      READ', '      WRITE']
         if self.options.time:
             titles = ['    TIME'] + titles
             current_time = time.strftime('%H:%M:%S ')
@@ -402,7 +424,7 @@ class IOTopUI(object):
                 if self.options.quiet <= int(first_time):
                     print ''.join(titles)
             for l in lines:
-                print l
+                print l.encode('utf-8')
             sys.stdout.flush()
         else:
             self.win.erase()
@@ -428,13 +450,9 @@ class IOTopUI(object):
             num_lines = min(len(lines), self.height - 2 - int(bool(status_msg)))
             for i in xrange(num_lines):
                 try:
-                    self.win.insstr(i + 2, 0, lines[i].encode('utf-8'))
+                    self.win.addstr(i + 2, 0, lines[i].encode('utf-8'))
                 except curses.error:
-                    exc_type, value, traceback = sys.exc_info()
-                    value = '%s win:%s i:%d line:%s' % \
-                                       (value, self.win.getmaxyx(), i, lines[i])
-                    value = str(value).encode('string_escape')
-                    raise exc_type, value, traceback
+                    pass
             if status_msg:
                 self.win.insstr(self.height - 1, 0, status_msg, curses.A_BOLD)
             self.win.refresh()
@@ -494,7 +512,10 @@ option, a to toggle the --accumulated option, q to quit, any other key to force
 a refresh.''' % sys.argv[0]
 
 def main():
-    locale.setlocale(locale.LC_ALL, '')
+    try:
+        locale.setlocale(locale.LC_ALL, '')
+    except locale.Error:
+        print 'unable to set locale, falling back to the default locale'
     parser = optparse.OptionParser(usage=USAGE, version='iotop ' + VERSION)
     parser.add_option('-o', '--only', action='store_true',
                       dest='only', default=False,
